# Data

Structure:

```
├── data               # Data, by default ignored
│   ├── external       # Data from third party sources.
│   ├── interim        # Transformed data
│   ├── processed      # Final model data
│   └── raw            # Immutable data dump, possibly
```
